"""
Formulaires génération des PV lettres individuelles
"""

from flask_wtf import FlaskForm
from wtforms import validators
from wtforms import SelectField
from wtforms.fields.simple import StringField, SubmitField
from flask_wtf.file import FileField, FileAllowed
from app.scodoc import sco_utils as scu


class GenerateLettresIndividuellesForm(FlaskForm):
    "form. choix paramètres lettres individuelles"

    # Les champs groupes et templates docx sont construits dynamiquement ci-dessous
    date_commission = StringField(
        "Date de la commission",
        validators=[
            validators.Optional(),
            validators.Length(min=1, max=80),
        ],
        default="",
        description="(format libre)",
        render_kw={"size": 50},
    )
    date_jury = StringField(
        "Date du Jury",
        validators=[
            validators.Optional(),
            validators.Length(min=1, max=80),
        ],
        default="",
        description="(si le jury a eu lieu)",
        render_kw={"size": 50},
    )
    template_select = SelectField(
        "Template docx", validators=[validators.DataRequired()], coerce=int
    )
    signature_img = FileField(
        label="Image signature",
        validators=[
            FileAllowed(
                scu.LOGOS_IMAGES_ALLOWED_TYPES,
                f"n'accepte que les fichiers image {', '.join(scu.LOGOS_IMAGES_ALLOWED_TYPES)}",
            ),
        ],
        description="Image de la signature (facultatif)",
    )
    submit = SubmitField("Générer le document")
    cancel = SubmitField("Annuler", render_kw={"formnovalidate": True})
