"""docx_template

Revision ID: f7dd70c0e50b
Revises: e0824c4f1b0b
Create Date: 2025-05-10 15:59:43.778944

"""

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "f7dd70c0e50b"
down_revision = "e0824c4f1b0b"
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        "docx_template",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.Text(), nullable=False),
        sa.Column("description", sa.Text(), server_default="", nullable=False),
        sa.Column("template", sa.LargeBinary(), nullable=False),
        sa.Column(
            "template_type",
            sa.Enum(
                "lettre_individuelle", "pv_jury", "autre", name="docx_template_type"
            ),
            nullable=False,
        ),
        sa.Column("dept_id", sa.Integer(), nullable=True),
        sa.Column("author_id", sa.Integer(), nullable=True),
        sa.Column(
            "date_creation",
            sa.DateTime(timezone=True),
            server_default=sa.text("now()"),
            nullable=False,
        ),
        sa.Column(
            "date_modification",
            sa.DateTime(timezone=True),
            server_default=sa.text("now()"),
            nullable=True,
        ),
        sa.ForeignKeyConstraint(["author_id"], ["user.id"], ondelete="SET NULL"),
        sa.ForeignKeyConstraint(["dept_id"], ["departement.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("id"),
    )
    with op.batch_alter_table("docx_template", schema=None) as batch_op:
        batch_op.create_index(
            batch_op.f("ix_docx_template_dept_id"), ["dept_id"], unique=False
        )
        batch_op.create_index(
            batch_op.f("ix_docx_template_name"), ["name"], unique=False
        )
        batch_op.create_index(
            batch_op.f("ix_docx_template_template_type"),
            ["template_type"],
            unique=False,
        )


def downgrade():

    with op.batch_alter_table("docx_template", schema=None) as batch_op:
        batch_op.drop_index(batch_op.f("ix_docx_template_template_type"))
        batch_op.drop_index(batch_op.f("ix_docx_template_name"))
        batch_op.drop_index(batch_op.f("ix_docx_template_dept_id"))

    op.drop_table("docx_template")
