"""Vérification sur une base réelle ou un dump
Charge les vues formsemestre, table recap et fiches étudiants
Ne vérifie pas le contenu, juste que la page se construit sans erreur.
"""

import pdb
from flask import g, Response

from app import db, log
import app as mapp
from app.but import bulletin_but

from app.models import Departement, FormSemestre, ScoPreference
from app.scodoc import sco_formsemestre_status, sco_page_etud, sco_recapcomplet
from app.scodoc.sco_bulletins import formsemestre_bulletinetud_dict


def disable_portal():
    """Désactive portail pour éviter appels externs durant le test"""
    log("disabling portal")
    for p in ScoPreference.query.filter_by(name="portal_url"):
        p.value = None
        db.session.add(p)
    db.session.commit()


def check_main_views(formsemestre_id: int | None = None):
    """Charge les vues principales de *tous* les semestres de la base"""
    disable_portal()
    flist = (
        FormSemestre.query.all()
        if formsemestre_id is None
        else [db.session.query(FormSemestre).get(formsemestre_id)]
    )
    flist.sort(key=lambda f: f.date_debut, reverse=True)
    mapp.set_sco_dept(Departement.query.first().acronym)
    for formsemestre in flist:
        print(
            f"""\n\n\n-------------------- checking {
                formsemestre.session_id()} formsemestre_id={formsemestre.id}\n"""
        )
        mapp.set_sco_dept(formsemestre.departement.acronym)
        # ----- STATUS
        g.etudid = None

        ans = sco_formsemestre_status.formsemestre_status(
            formsemestre_id=formsemestre.id
        )
        assert isinstance(ans, (str, Response))
        # ----- TABLE RECAP
        ans = sco_recapcomplet.formsemestre_recapcomplet(formsemestre.id)
        assert isinstance(ans, (str, Response))
        # ----- FICHES ETUDIANTS ET BULLETINS
        for etud in formsemestre.etuds:
            g.etudid = None
            ans = sco_page_etud.fiche_etud(etud.id)
            assert isinstance(ans, (str, Response))
            print(".", flush=True, end="")
            # Bulletins / PVs
            if formsemestre.formation.is_apc():
                bulletins_sem = bulletin_but.BulletinBUT(formsemestre)
                bul_dict = bulletins_sem.bulletin_etud_complet(etud)
            else:
                bul_dict = formsemestre_bulletinetud_dict(formsemestre.id, etud.id)
            assert isinstance(bul_dict, dict)
    print("OK")
